pub unsafe extern "C" fn uci_free_context(ctx: *mut uci_context)Expand description
uci_free_context: Free the uci context including all of its data
pub unsafe extern "C" fn uci_free_context(ctx: *mut uci_context)uci_free_context: Free the uci context including all of its data